@@ -256,7 +256,7 @@ static GOptionEntry options[] = {
    N_("For test purpose, run in a loop all the activities"), NULL},
 
   {"debug", 'D', 0, G_OPTION_ARG_NONE, &popt_debug,
-   N_("display debug informations on the console."), NULL},
+   N_("display debug information on the console."), NULL},
 
   {"version", 'v', 0, G_OPTION_ARG_NONE, &popt_version,
    N_("Print the version of " PACKAGE), NULL},
@@ -1627,7 +1627,7 @@ main (int argc, char *argv[])
   sugar_setup(&argc, &argv);
 
   /* Argument parsing */
-  context = g_option_context_new(" - An educational software for chilren 2 to 10");
+  context = g_option_context_new(" - An educational software for children 2 to 10");
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
   g_option_context_parse (context, &argc, &argv, &error);
