@@ -155,7 +155,7 @@ void gc_help_start (GcomprisBoard *gcomprisBoard)
 		       y_start,
 		       -1,
 		       GTK_ANCHOR_CENTER,
-		       "font", gc_skin_font_title,
+		       "font", gc_skin_font_subtitle,
 		       "fill-color-rgba", gc_skin_color_title,
 		       NULL);
 
@@ -287,7 +287,12 @@ void gc_help_start (GcomprisBoard *gcomprisBoard)
 
   // default text to display
 
-  if(prerequisite)
+  if(manual)
+    {
+      text_to_display = manual;
+      select_item(item_manual, item_manual_text);
+    }
+  else if(prerequisite)
     {
       text_to_display = prerequisite;
       select_item(item_prerequisite, item_prerequisite_text);
@@ -297,11 +302,6 @@ void gc_help_start (GcomprisBoard *gcomprisBoard)
       text_to_display = goal;
       select_item(item_goal, item_goal_text);
     }
-  else if(manual)
-    {
-      text_to_display = manual;
-      select_item(item_manual, item_manual_text);
-    }
   else if(credit)
     {
       text_to_display = credit;
@@ -435,7 +435,6 @@ item_event_help (GooCanvasItem  *item,
 		 gchar *data)
 {
 
-  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
   if(!strcmp((char *)data, "ok"))
     {
       gc_help_stop();
