@@ -247,6 +247,7 @@ static void hanoi_next_level()
     case 3:
       number_of_item_x = 5;
       number_of_item_y = 6;
+      break;
     case 4:
       number_of_item_x = 6;
       number_of_item_y = 7;
@@ -537,7 +538,7 @@ hanoi_create_item(GooCanvasItem *parent)
 				   0,
 				   -1,
 				   GTK_ANCHOR_NORTH,
-				   "font", "sans bold 14",
+				   "font", gc_skin_font_board_medium_bold,
 				   "fill-color", "white",
 				   NULL);
 
