@@ -77,6 +77,8 @@ class Gcompris_lang:
 
     self.langLib = LangLib(gcompris.DATA_DIR + "/lang/words.xml")
     self.chapters = self.langLib.getChapters()
+    self.currentExercise = None
+    self.currentExerciseModes = []
 
     if self.gcomprisBoard.mode == "":
       gcompris.utils.dialog("ERROR, missing 'mode' in the xml menu to specify the chapter",
@@ -107,20 +109,18 @@ dialogue to\nenable the sound."), None)
 
     gcompris.bar_set_level(self.gcomprisBoard)
 
-    self.currentExerciseModes = []
-    self.currentExercise = None
-    self.currentLesson = self.langLib.getLesson(self.currentChapterName,
-                                                self.gcomprisBoard.level - 1)
-
     readyButton = TextButton(400, 255, ' ' * 20 + _('I am Ready') + ' ' * 20,
                              self.rootitem, 0x11AA11FFL)
     readyButton.getBackground().connect("button_press_event",
                                         self.ready_event, readyButton)
 
+    self.pause(1);
 
 
   def ready_event(self, widget, target, event, button):
     button.destroy()
+    self.currentLesson = self.langLib.getLesson(self.currentChapterName,
+                                                self.gcomprisBoard.level - 1)
     self.displayLesson( self.currentLesson )
     self.displayImage( self.currentLesson.getTriplets()[self.currentTripletId] )
     self.pause(0);
@@ -212,7 +212,8 @@ dialogue to\nenable the sound."), None)
     # the game is won
     if(self.gamewon == 1 and pause == 0):
       self.gamewon = 0
-      self.next_level()
+      if not self.runExercise():
+        self.next_level()
 
     return
 
@@ -233,6 +234,10 @@ dialogue to\nenable the sound."), None)
     self.gcomprisBoard.sublevel = 1;
     gcompris.bar_set_level(self.gcomprisBoard)
 
+    # We are not yet started
+    if self.board_paused:
+      return
+
     if self.currentExercise:
       self.currentExercise.stop()
       self.currentExercise = None
@@ -425,9 +430,9 @@ dialogue to\nenable the sound."), None)
     self.displayImage( self.currentLesson.getTriplets()[self.currentTripletId] )
 
   def win(self):
-    if not self.runExercise():
-      self.gamewon = 1
-      gcompris.bonus.display(gcompris.bonus.WIN, gcompris.bonus.FLOWER)
+    self.gamewon = 1
+    gcompris.bonus.display(gcompris.bonus.WIN, gcompris.bonus.FLOWER)
+    self.gcomprisBoard.sublevel += 1;
 
   def loose(self):
     self.gamewon = 0
